Welcome to YTubeInsight's documentation!
========================================

YTubeInsight is a Python package for effortless YouTube channel analytics. It allows you to track video counts, extract details, and gain insights from YouTube channels.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`